# ncluster

## Usage
Install pip, tmux, Python 3.6 (see below), then

```
pip install -r https://raw.githubusercontent.com/diux-dev/ncluster/master/requirements.txt
pip install ncluster
```

### Extra
An example of installing pip/tmux/python 3.6 on MacOS

1. Download Anaconda distribution following https://conda.io/docs/user-guide/install/index.html
2. Install tmux through homebrew: https://brew.sh/, then `brew install tmux`

Then

```
conda create -n new python=3.6 -y
conda activate new
```
